@@ -6,8 +6,9 @@ tools provided by aiida-kkr plugin
 from .common_workfunctions import (
     update_params_wf, prepare_VCA_structure_wf, prepare_2Dcalc_wf, test_and_get_codenode, get_inputs_kkr,
     get_inputs_kkrimporter, get_inputs_voronoi, get_inputs_kkrimp, get_parent_paranode,
-    generate_inputcard_from_structure, check_2Dinput_consistency, structure_from_params, vca_check, find_cluster_radius
+    generate_inputcard_from_structure, check_2Dinput_consistency, structure_from_params, vca_check
 )
+from .find_cluster_radius import find_cluster_radius
 from .plot_kkr import plot_kkr
 from .parse_dos import parse_dosfiles
 from .tools_kkrimp import modify_potential, rotate_onto_z, find_neighbors, make_scoef
@@ -16,6 +17,7 @@ from masci_tools.io.kkr_params import kkrparams
 from .multi_imps_data_extract import MultiImpuritiesData
 from .kick_out_core_states import *
 from .neworder_potential import *
+from .find_parent import get_calc_from_remote, get_remote, get_parent
 
 
 # expose structure finder from VoronoiCalculation
@@ -28,8 +30,11 @@ def find_parent_structure(calc_or_remote, return_voro=False):
     :param calc_or_remote: CalcJobNode or RemoteData node of VoronoiCalculation or KkrCalculation
     :return struc: parent StructureData node
     """
-    from aiida_kkr.calculations.voro import VoronoiCalculation
+    from .find_parent import find_parent_structure
 
-    struc, voro_calc = VoronoiCalculation.find_parent_structure(calc_or_remote)
+    struc, voro_calc = find_parent_structure(calc_or_remote)
 
-    return struc
+    if return_voro:
+        return struc, voro_calc
+    else:
+        return struc
