@@ -18,7 +18,8 @@ from aiida_kkr.workflows.kkr_imp_sub import kkr_imp_sub_wc, clean_sfd
 import numpy as np
 from aiida_kkr.tools.save_output_nodes import create_out_dict_node
 
-__copyright__ = (u'Copyright (c), 2017, Forschungszentrum Jülich GmbH, ' 'IAS-1/PGI-1, Germany. All rights reserved.')
+__copyright__ = (u'Copyright (c), 2017, Forschungszentrum Jülich GmbH, '
+                 'IAS-1/PGI-1, Germany. All rights reserved.')
 __license__ = 'MIT license, see LICENSE.txt file'
 __version__ = '0.9.0'
 __contributors__ = (u'Fabian Bertoldo', u'Philipp Rüßmann')
@@ -82,7 +83,7 @@ class kkr_imp_wc(WorkChain):
         """
         if not silent:
             print(f'Version of workflow: {self._workflowversion}')
-        return self._options_default, self._wf_default, self._voro_aux_default
+        return self._options_default.copy(), self._wf_default.copy(), self._voro_aux_default.copy()
 
     @classmethod
     def define(cls, spec):
@@ -92,6 +93,19 @@ class kkr_imp_wc(WorkChain):
 
         super(kkr_imp_wc, cls).define(spec)
 
+        # expose inputs of sub workflow
+        # TODO also expose the other inputs in next release, but put deprecation warnings in first
+        spec.expose_inputs(
+            kkr_imp_sub_wc,
+            namespace='scf',
+            include=(
+                # 'kkrimp',
+                # 'options',
+                # 'wf_parameters',
+                'params_overwrite'
+            )
+        )
+
         # define the inputs of the workflow
         spec.input('kkr', valid_type=Code, required=True, help='KKRhost code used to run GF writeout step.')
         spec.input(
@@ -762,6 +776,8 @@ class kkr_imp_wc(WorkChain):
         builder.remote_data = gf_remote
         if 'remote_data_gf_Efshift' in self.inputs:
             builder.remote_data_Efshift = self.inputs.remote_data_gf_Efshift
+        if 'params_overwrite' in self.inputs.scf:
+            builder.params_overwrite = self.inputs.scf.params_overwrite
         builder.wf_parameters = kkrimp_params
         future = self.submit(builder)
 
